﻿using System;
using System.Diagnostics;
using Windows.UI.Core;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Newtonsoft.Json;
using WebViewDemo.Models;

namespace WebViewDemo
{
    public sealed partial class MainPage
    {
        public MainPage()
        {
            InitializeComponent();

            Loaded += MainPage_Loaded;
        }

        private void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            WebView1.Navigate(new Uri("ms-appx-web:///Assets/Html/sample.html"));
            WebView2.Navigate(new Uri("ms-appx-web:///Assets/Html/sample.html"));
            WebView3.Navigate(new Uri("ms-appx-web:///Assets/Html/sample.html"));
        }

        private async void ButtonBase_OnClick(object sender, RoutedEventArgs e)
        {
            var btn = (Button) sender;
            if (btn.Content != null)
            {
                switch (btn.Content.ToString())
                {
                    case "back":
                        //WebView1.GoBack();
                        //await WebView1.InvokeScriptAsync("eval", new []{"history.go(-1)"});
                        break;
                    case "refresh":
                        //WebView1.Refresh();
                        //await WebView1.InvokeScriptAsync("eval", new[] { "history.go()" });        
                        break;
                    case "forward":
                        //WebView1.GoForward();
                        //await WebView1.InvokeScriptAsync("eval", new[] { "history.go(1)" });
                        break;
                }
            }
        }

        private void WebView_OnScriptNotify(object sender, NotifyEventArgs e)
        {
            //这个事件函数可以监听到JS通知的消息，消息类型为文本
            //这里统一消息格式为：JsInvokeModel
            var model = JsonConvert.DeserializeObject<JsInvokeModel>(e.Value);
            switch (model.Type)
            {
                case "image":
                    Info.Text = e.Value;
                    break;
                case "swiperight":
                    Info.Text = e.Value;
                    if (pivot.Items != null)
                    {
                        if (pivot.SelectedIndex > 0)
                        {
                            pivot.SelectedIndex--;
                        }
                        else
                        {
                            pivot.SelectedIndex = pivot.Items.Count - 1;
                        }
                    }
                    break;
                case "swipeleft":
                    Info.Text = e.Value;
                    if (pivot.Items != null)
                    {
                        if (pivot.SelectedIndex < pivot.Items.Count - 1)
                        {
                            pivot.SelectedIndex++;
                        }
                        else
                        {
                            pivot.SelectedIndex = 0;
                        }
                    }
                    break;
                case "text":
                    Info.Text = e.Value;
                    break;
            }
        }

        private async void WebView3_OnDOMContentLoaded(WebView sender, WebViewDOMContentLoadedEventArgs args)
        {
            //1、动态加载css
            var js = @"var myCss = document.createElement(""link"");
                myCss.rel = ""stylesheet"";
                myCss.type = ""text/css"";
                myCss.href = ""ms-appx-web:///Assets/Html/css/default.css"";
                document.body.appendChild(myCss);";

            await sender.InvokeScriptAsync("eval", new[] {js});

            //2、动态加载js库（json2）
            js = @"var myScript = document.createElement(""script"");
                myScript.type = ""text/javascript"";
                myScript.src = ""ms-appx-web:///Scripts/json2.min.js"";
                document.body.appendChild(myScript);";

            await sender.InvokeScriptAsync("eval", new[] {js});

            //3、调用js执行自定义代码（为图片添加点击事件，并通知）
            js = @"var imgs = document.getElementsByTagName(""img"");
                   for (var i = 0, len = imgs.length; i < len; i++) {
                       imgs[i].onclick = function (e) {
                           var jsonObj = { type: 'image', content1: this.src };
                           window.external.notify(JSON.stringify(jsonObj));
                       };
                   }";
            await sender.InvokeScriptAsync("eval", new[] {js});


            //4、动态加载手势
            js = @"var myScript = document.createElement(""script"");
                myScript.type = ""text/javascript"";
                myScript.src = ""ms-appx-web:///Assets/Html/js/gesture.js"";
                document.body.appendChild(myScript);";
            await sender.InvokeScriptAsync("eval", new[] {js});

            //5、手势监听
            js = @"var target = document.getElementsByTagName(""body"")[0];
                   prepareTarget(target, eventListener);";
            await sender.InvokeScriptAsync("eval", new[] {js});
        }
    }
}
